% classify Nearest: Determines to which trained face a new face 
% corresponds. This performed by a nearest neighbor alogrithm, which uses 
% the Euclidean distance to determine relationship between images.
%
% Useage: [index, distance] = 
%   classifyNearest(path,testFiles,side,trainWeights,v,avg,threshold)
%
% 'weights'     - Projected test images.
% 'trainWeights'- Projected trained images.
% 'threshold'   - Minimum distance for face matching.
%
% 'index'       - The index to the training image to which a test image 
%                   matches in the trainfiles.
% 'distance'    - Distance between images.

function [index, distance] = ...
    classifyNearest(weights,trainWeights,threshold)

skip = 0;
cosdist = false;

index = ones(1,size(weights,2));
distance = ones(size(weights,2),1);
dist = ones(size(trainWeights,2),1);

for i = 1 : size(weights,2)
%     imgM = imgs(:,i);

    % Calculate Weights for Image in Current Eigenspace
    weight = weights(:,i);

    % Calculate Euclidean distance between weight of current image and the
    % weight of each training image.
    for j = 1 : size(trainWeights,2)
        w1 = weight;
        w2 = trainWeights(:,j);
        if skip >= 1
            w1(1:skip) = 0;
            w2(1:skip) = 0;
        end        
        if cosdist
            dist(j,1) = dot(w1, w2)/(norm(w1)*norm(w2));
        else
            dist(j,1) = norm(w1 - w2);
        end
    end

    % Find minimum distance and save its index.
    if cosdist
        [Y,temp] = max(dist(:,1));
    else
        [Y,temp] = min(dist(:,1));
    end
    distance(1,i) = Y;
    
    % If distance is greater than a predefined value, the image is not
    % recognized and set value to Inf.
    if dist(temp,1) > threshold && threshold ~= -1
        index(1,i) = Inf;
    else
        index(1,i) = temp;
    end
end

return