% createTrainTest: Reads in images and divides them into a training and
% testing set based on the trainPercent variable. These images are read
% into a matrix of column vectors.
%
% Useage: [trainFaces, testFaces, trainFiles, testFiles] 
%                   = createTrainTest(path, ext, trainPercent)
%
% 'path'        - Path to the folder where all the files are in.
% 'ext'         - File extension of images in path folder.
% 'trainPercent'- Percentange of images used for training.
%
% 'trainFaces'  - Matrix of column vectors containing testing images
% 'testFaces'   - Matrix of column vectors containing training images
% 'trainFiles'  - Contains training files information.
% 'testFiles'   - Contain testing files information.
%

function  [trainFaces, testFaces, trainFiles, testFiles] = ...
    createTrainTest(path, ext, trainPercent, side)

files = dir([path '/*.' ext]);

% Read images into matrix of column vectors.
images = [];
for i = 1 : length(files)
    disp(i);
    im = double(imread([path '/' files(i).name]));
%     im = imresize(im, [side side]);
    images = [images im(:)];
end

[n, m] = size(images);

% Determine number of training images based on percentage.
nTrain = floor(m * trainPercent / 100);

% Randomly order the images.
% images = images(:,randperm(size(images,2)));

% Divide training and testing images.
trainFaces = images(:,1:nTrain);
testFaces = images(:,nTrain+1:end);

trainFiles = files(1:nTrain);
testFiles = files(nTrain+1:end);

return