% This script file runs all of the parts of the code. Reading images,
% computing eigenvectors, matching, and writing results to html for easy
% viewing.
%
% Notes:
% - I converted all RAW images to jpegs using a matlab script not
% submitted.

clc;    % Clear screen
clear;  % Clear memory

% Parameters for functions (SELECT ONE OF THESE LOCATIONS)
trainPercent = 60;          % What percentage of the data is training
ext = 'jpg';                % File extension of images
randSeed = 1;               % Random seed for generator
omitThresh = 1;             % People with less than these many faces are 
                            %       omitted
side = 128;                 % Size of images
threshold = -1;             % Treshold for NN - ignore for now...

attData = false;            % Select true if working with ATT formatted data
loadFromMat = true;         % Select true if loading from saved mat file
%%

if(~attData)
    if(~loadFromMat)
        
        imPath = '../images/mitjpeg/';     % Location of files - change if necessary

        disp('Creating Training and Testing Set');

        % This function simply randomly selects which images are training and 
        % which are testing and returns the loaded training and testing images 
        % in a column vector matrix. It also provides the necessary files
        [trainFaces, testFaces, trainFiles, testFiles] = ...
            createTrainTest(imPath, ext, trainPercent, side);

        save 'faces.mat' trainFaces testFaces trainFiles testFiles

        disp('Done Creating Training and Testing Set');
    else
        load 'faces.mat';
    end
else
    
    imPath = '../images/attjpeg/';  % Location of files - change if necessary
    
    if(~loadFromMat)
        [trainFiles, testFiles] = getTrainTestSet(imPath, trainPercent, ext, randSeed);
        [trainFaces,trainIds] = batchPictures(imPath, trainFiles, side, 0);
        [testFaces,testIds] = batchPictures(imPath, testFiles, side, 0);
        
        save 'attFaces.mat' trainFaces testFaces  trainIds testIds trainFiles testFiles;
    else
        load 'attFaces.mat';
    end
end

trainFaces = double(trainFaces);
testFaces = double(testFaces);

% Compute average of training images
avgTrainFaces = mean(trainFaces,2);

% Normalize the training images
for i = 1 : size(trainFaces, 2)
    trainFaces(:,i) = trainFaces(:,i) - avgTrainFaces;
end

% Normalize the testing images
for i = 1 : size(testFaces, 2)
    testFaces(:,i) = testFaces(:,i) - avgTrainFaces;
end

%%
% Computing Eigenvectors and Eigenvalues
disp('Computing Eigenspace');
[U,S] = svd(trainFaces, 'econ');
disp('Done Computing Eigenspace');


%%
% Select top Eigenvectors to represent the subspace
eigenVectors = U(:,1:10);

% Project train faces into eigenspace
trainWeights = eigenVectors' * trainFaces;

% Project test faces into eigenspace
testWeights = eigenVectors' * testFaces;

% Perform Classification
[index, distance] = classifyNearest(testWeights,trainWeights,threshold);

% Saves results in case you'd like to see them again.
save results.mat;

disp('Done.....');

%%
% Saves results to HTML for easy viewing...
writeToHTML
disp('Finished Writing HTML');

if(attData)
    accuracy = sum(testIds == trainIds(index)) * 100 / length(testIds);
    disp(['Accuracy: ' num2str(accuracy) '%']);
end
